import fs from "node:fs/promises";
import chalk from "chalk";
import { $ } from "execa";
import prettier from "prettier";
import { readFileAsJson } from "../../shared/readFileAsJson.js";
export async function addOwnerAsAllContributor(owner) {
    let user;
    try {
        user = JSON.parse((await $ `gh api user`).stdout).login;
    }
    catch {
        console.warn(chalk.gray(`Couldn't authenticate GitHub user, falling back to the provided owner name '${owner}'.`));
        user = owner;
    }
    await $ `npx -y all-contributors-cli add ${user} ${[
        "code",
        "content",
        "doc",
        "ideas",
        "infra",
        "maintenance",
        "projectManagement",
        "tool",
    ].join(",")}`;
    const existingContributors = (await readFileAsJson("./.all-contributorsrc"));
    if (!isValidAllContributorsData(existingContributors)) {
        throw new Error(`Invalid .all-contributorsrc: ${JSON.stringify(existingContributors)}`);
    }
    await fs.writeFile("./.all-contributorsrc", prettier.format(JSON.stringify({
        ...existingContributors,
        contributors: existingContributors.contributors
            .filter(({ login }) => [user, "JoshuaKGoldberg"].includes(login))
            .map((contributor) => contributor.login === "JoshuaKGoldberg"
            ? { ...contributor, contributions: ["tool"] }
            : contributor),
    }), { parser: "json" }));
}
function isValidAllContributorsData(value) {
    return !!value && typeof value === "object" && "contributors" in value;
}
//# sourceMappingURL=addOwnerAsAllContributor.js.map