import { parseArgs } from "node:util";
import { titleCase } from "title-case";
import { getDefaultSettings } from "./defaults.js";
import { ensureRepositoryExists } from "./ensureRepositoryExists.js";
import { getOctokit } from "./getOctokit.js";
import { optionalDefault } from "./optionalDefault.js";
import { PrefillPrompter } from "./PrefillPrompter.js";
export async function getInputValuesAndOctokit(args, defaults = {}) {
    const { defaultOwner, defaultRepository } = await getDefaultSettings();
    const { values } = parseArgs({
        args,
        options: {
            author: { type: "string" },
            description: { type: "string" },
            email: { type: "string" },
            funding: { type: "string" },
            owner: { type: "string" },
            releases: { type: "boolean" },
            repository: { type: "string" },
            unitTests: { type: "boolean" },
            title: { type: "string" },
            "skip-api": { type: "boolean" },
            "skip-removal": { type: "boolean" },
            "skip-restore": { type: "boolean" },
            "skip-uninstall": { type: "boolean" },
        },
        tokens: true,
        strict: false,
    });
    const prompter = new PrefillPrompter();
    const owner = await prompter.getPrefillOrPromptedValue("owner", values.owner, "What owner or user will the repository be under?", defaultOwner);
    const octokit = await getOctokit(!!values["skip-api"]);
    prompter.reset();
    const repository = await ensureRepositoryExists(octokit, owner, await prompter.getPrefillOrPromptedValue("repository", values.repository, "What will the kebab-case name of the repository be?", defaultRepository));
    const title = await prompter.getPrefillOrPromptedValue("title", values.title, "What will the Title Case title of the repository be?", titleCase(repository).replaceAll("-", " "));
    const description = await prompter.getPrefillOrPromptedValue("description", values.description, "How would you describe the new package?", "A very lovely package. Hooray!");
    return {
        octokit,
        values: {
            author: await optionalDefault(values.author, defaults.author),
            email: await optionalDefault(values.email, defaults.email),
            funding: await optionalDefault(values.funding, defaults.funding),
            releases: await optionalDefault(values.releases, defaults.releases),
            unitTests: await optionalDefault(values.unitTests, defaults.unitTests),
            description,
            owner,
            repository,
            skipApi: !!values["skip-api"],
            skipRemoval: !!values["skip-removal"],
            skipRestore: !!values["skip-restore"],
            skipUninstalls: !!values["skip-uninstalls"],
            title,
        },
    };
}
//# sourceMappingURL=inputs.js.map